==> ejc-sddjsorg-api-3.0.0-20211015.112102-15-sources.jar: com/ejianc/business/production/vo/NoneCurrencyVO.java <==
package com.ejianc.business.production.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产权登记-非货币出资
 * 
 * @author generator
 * 
 */
public class NoneCurrencyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long pid; // 主表id(申请单id)
    private java.lang.String inOutCaptail; // 内/外部出资方
    private java.lang.String captailName; // 出资方名称
    private java.lang.String unifiedSocialCreditCode; // 统一社会信用编码
    private java.lang.String captailType; // 出资人类别
    private java.math.BigDecimal subscribedCapital; // 认缴资本
    private java.lang.String subscribedCapitalBig; // 认缴资本(大写)
    private java.math.BigDecimal paidCapital; // 实缴资本
    private java.lang.String paidCapitalBig; // 实缴资本(大写)
    private java.math.BigDecimal equityRatio; // 股权比例
    private java.lang.String assetAppraisalFilingNo; // 产评估备案编号
    private java.math.BigDecimal assessmentValue; // 评估值
    private java.lang.String assessmentValueBig; // 评估值(大写)
    private java.lang.Integer hasRecord; // 是否中电建备案
    private java.lang.String assetItem; // 资产项目
    

    /**
     * 主表id(申请单id)
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id(申请单id)
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 内/外部出资方
     */
    public java.lang.String getInOutCaptail() {
        return inOutCaptail;
    }

    /**
     * 内/外部出资方
     */
    public void setInOutCaptail(java.lang.String inOutCaptail) {
        this.inOutCaptail = inOutCaptail;
    }
    /**
     * 出资方名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用编码
     */
    public java.lang.String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用编码
     */
    public void setUnifiedSocialCreditCode(java.lang.String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 出资人类别
     */
    public java.lang.String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(java.lang.String captailType) {
        this.captailType = captailType;
    }
    /**
     * 认缴资本
     */
    public java.math.BigDecimal getSubscribedCapital() {
        return subscribedCapital;
    }

    /**
     * 认缴资本
     */
    public void setSubscribedCapital(java.math.BigDecimal subscribedCapital) {
        this.subscribedCapital = subscribedCapital;
    }
    /**
     * 认缴资本(大写)
     */
    public java.lang.String getSubscribedCapitalBig() {
        return subscribedCapitalBig;
    }

    /**
     * 认缴资本(大写)
     */
    public void setSubscribedCapitalBig(java.lang.String subscribedCapitalBig) {
        this.subscribedCapitalBig = subscribedCapitalBig;
    }
    /**
     * 实缴资本
     */
    public java.math.BigDecimal getPaidCapital() {
        return paidCapital;
    }

    /**
     * 实缴资本
     */
    public void setPaidCapital(java.math.BigDecimal paidCapital) {
        this.paidCapital = paidCapital;
    }
    /**
     * 实缴资本(大写)
     */
    public java.lang.String getPaidCapitalBig() {
        return paidCapitalBig;
    }

    /**
     * 实缴资本(大写)
     */
    public void setPaidCapitalBig(java.lang.String paidCapitalBig) {
        this.paidCapitalBig = paidCapitalBig;
    }
    /**
     * 股权比例
     */
    public java.math.BigDecimal getEquityRatio() {
        return equityRatio;
    }

    /**
     * 股权比例
     */
    public void setEquityRatio(java.math.BigDecimal equityRatio) {
        this.equityRatio = equityRatio;
    }
    /**
     * 产评估备案编号
     */
    public java.lang.String getAssetAppraisalFilingNo() {
        return assetAppraisalFilingNo;
    }

    /**
     * 产评估备案编号
     */
    public void setAssetAppraisalFilingNo(java.lang.String assetAppraisalFilingNo) {
        this.assetAppraisalFilingNo = assetAppraisalFilingNo;
    }
    /**
     * 评估值
     */
    public java.math.BigDecimal getAssessmentValue() {
        return assessmentValue;
    }

    /**
     * 评估值
     */
    public void setAssessmentValue(java.math.BigDecimal assessmentValue) {
        this.assessmentValue = assessmentValue;
    }
    /**
     * 评估值(大写)
     */
    public java.lang.String getAssessmentValueBig() {
        return assessmentValueBig;
    }

    /**
     * 评估值(大写)
     */
    public void setAssessmentValueBig(java.lang.String assessmentValueBig) {
        this.assessmentValueBig = assessmentValueBig;
    }
    /**
     * 是否中电建备案
     */
    public java.lang.Integer getHasRecord() {
        return hasRecord;
    }

    /**
     * 是否中电建备案
     */
    public void setHasRecord(java.lang.Integer hasRecord) {
        this.hasRecord = hasRecord;
    }
    /**
     * 资产项目
     */
    public java.lang.String getAssetItem() {
        return assetItem;
    }

    /**
     * 资产项目
     */
    public void setAssetItem(java.lang.String assetItem) {
        this.assetItem = assetItem;
    }
    
}

==> ejc-sddjsorg-api-3.0.0-20211026.022736-78-sources.jar: com/ejianc/business/production/vo/NoneCurrencyVO.java <==
package com.ejianc.business.production.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产权登记-非货币出资
 * 
 * @author generator
 * 
 */
public class NoneCurrencyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long pid; // 主表id(申请单id)
    private java.lang.String inOutCaptail; // 内/外部出资方
    private java.lang.String captailName; // 出资方名称
    private java.lang.String unifiedSocialCreditCode; // 统一社会信用编码
    private java.lang.String captailType; // 出资人类别
    private java.math.BigDecimal subscribedCapital; // 认缴资本
    private java.lang.String subscribedCapitalBig; // 认缴资本(大写)
    private java.math.BigDecimal paidCapital; // 实缴资本
    private java.lang.String paidCapitalBig; // 实缴资本(大写)
    private java.math.BigDecimal equityRatio; // 股权比例
    private java.lang.String assetAppraisalFilingNo; // 产评估备案编号
    private java.math.BigDecimal assessmentValue; // 评估值
    private java.lang.String assessmentValueBig; // 评估值(大写)
    private java.lang.Integer hasRecord; // 是否中电建备案
    private java.lang.String assetItem; // 资产项目

    private Boolean whetherShareholder;//是否新股东
    private String contributionType; // 出资类别
    private BigDecimal captailPrice;//出资作价
    private String captailPriceBig;//出资作价大写
    private BigDecimal capitalIncreaseFrontRatio;
    private String assessmentObject;//评估对象

    /**
     * 主表id(申请单id)
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id(申请单id)
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 内/外部出资方
     */
    public java.lang.String getInOutCaptail() {
        return inOutCaptail;
    }

    /**
     * 内/外部出资方
     */
    public void setInOutCaptail(java.lang.String inOutCaptail) {
        this.inOutCaptail = inOutCaptail;
    }
    /**
     * 出资方名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用编码
     */
    public java.lang.String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用编码
     */
    public void setUnifiedSocialCreditCode(java.lang.String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 出资人类别
     */
    public java.lang.String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(java.lang.String captailType) {
        this.captailType = captailType;
    }
    /**
     * 认缴资本
     */
    public java.math.BigDecimal getSubscribedCapital() {
        return subscribedCapital;
    }

    /**
     * 认缴资本
     */
    public void setSubscribedCapital(java.math.BigDecimal subscribedCapital) {
        this.subscribedCapital = subscribedCapital;
    }
    /**
     * 认缴资本(大写)
     */
    public java.lang.String getSubscribedCapitalBig() {
        return subscribedCapitalBig;
    }

    /**
     * 认缴资本(大写)
     */
    public void setSubscribedCapitalBig(java.lang.String subscribedCapitalBig) {
        this.subscribedCapitalBig = subscribedCapitalBig;
    }
    /**
     * 实缴资本
     */
    public java.math.BigDecimal getPaidCapital() {
        return paidCapital;
    }

    /**
     * 实缴资本
     */
    public void setPaidCapital(java.math.BigDecimal paidCapital) {
        this.paidCapital = paidCapital;
    }
    /**
     * 实缴资本(大写)
     */
    public java.lang.String getPaidCapitalBig() {
        return paidCapitalBig;
    }

    /**
     * 实缴资本(大写)
     */
    public void setPaidCapitalBig(java.lang.String paidCapitalBig) {
        this.paidCapitalBig = paidCapitalBig;
    }
    /**
     * 股权比例
     */
    public java.math.BigDecimal getEquityRatio() {
        return equityRatio;
    }

    /**
     * 股权比例
     */
    public void setEquityRatio(java.math.BigDecimal equityRatio) {
        this.equityRatio = equityRatio;
    }
    /**
     * 产评估备案编号
     */
    public java.lang.String getAssetAppraisalFilingNo() {
        return assetAppraisalFilingNo;
    }

    /**
     * 产评估备案编号
     */
    public void setAssetAppraisalFilingNo(java.lang.String assetAppraisalFilingNo) {
        this.assetAppraisalFilingNo = assetAppraisalFilingNo;
    }
    /**
     * 评估值
     */
    public java.math.BigDecimal getAssessmentValue() {
        return assessmentValue;
    }

    /**
     * 评估值
     */
    public void setAssessmentValue(java.math.BigDecimal assessmentValue) {
        this.assessmentValue = assessmentValue;
    }
    /**
     * 评估值(大写)
     */
    public java.lang.String getAssessmentValueBig() {
        return assessmentValueBig;
    }

    /**
     * 评估值(大写)
     */
    public void setAssessmentValueBig(java.lang.String assessmentValueBig) {
        this.assessmentValueBig = assessmentValueBig;
    }
    /**
     * 是否中电建备案
     */
    public java.lang.Integer getHasRecord() {
        return hasRecord;
    }

    /**
     * 是否中电建备案
     */
    public void setHasRecord(java.lang.Integer hasRecord) {
        this.hasRecord = hasRecord;
    }
    /**
     * 资产项目
     */
    public java.lang.String getAssetItem() {
        return assetItem;
    }

    /**
     * 资产项目
     */
    public void setAssetItem(java.lang.String assetItem) {
        this.assetItem = assetItem;
    }

    public Boolean getWhetherShareholder() {
        return whetherShareholder;
    }

    public void setWhetherShareholder(Boolean whetherShareholder) {
        this.whetherShareholder = whetherShareholder;
    }

    public String getContributionType() {
        return contributionType;
    }

    public void setContributionType(String contributionType) {
        this.contributionType = contributionType;
    }

    public BigDecimal getCaptailPrice() {
        return captailPrice;
    }

    public void setCaptailPrice(BigDecimal captailPrice) {
        this.captailPrice = captailPrice;
    }

    public String getCaptailPriceBig() {
        return captailPriceBig;
    }

    public void setCaptailPriceBig(String captailPriceBig) {
        this.captailPriceBig = captailPriceBig;
    }

    public BigDecimal getCapitalIncreaseFrontRatio() {
        return capitalIncreaseFrontRatio;
    }

    public void setCapitalIncreaseFrontRatio(BigDecimal capitalIncreaseFrontRatio) {
        this.capitalIncreaseFrontRatio = capitalIncreaseFrontRatio;
    }

    public String getAssessmentObject() {
        return assessmentObject;
    }

    public void setAssessmentObject(String assessmentObject) {
        this.assessmentObject = assessmentObject;
    }
}
